[SCM] live-build branch, debian, updated. debian/3.0_a59-1

Daniel Baumann daniel at debian.org
Wed Sep 26 12:49:24 UTC 2012


The following commit has been merged in the debian branch:
commit 9228a0ca66324c01ca4b32b40749923f2bf5e3a8
Author: Daniel Baumann <daniel at debian.org>
Date:   Thu Sep 20 16:53:03 2012 +0200

    Renaming volatile options refering to volatile archive to updates to match current archive namings.

diff --git a/manpages/de/lb.de.1 b/manpages/de/lb.de.1
index 9e674ae..48fe967 100644
--- a/manpages/de/lb.de.1
+++ b/manpages/de/lb.de.1
@@ -3,7 +3,7 @@
 .\" This file was generated with po4a. Translate the source file.
 .\"
 .\"*******************************************************************
-.TH LIVE\-BUILD 1 2012\-08\-27 3.0~a58\-1 "Debian Live Project"
+.TH LIVE\-BUILD 1 2012\-09\-20 3.0~a58\-1 "Debian Live Project"
 
 .SH NAME
 \fBlb\fP \- wrapper for live\-build programs
diff --git a/manpages/de/lb_binary.de.1 b/manpages/de/lb_binary.de.1
index acb17a8..6b7c381 100644
--- a/manpages/de/lb_binary.de.1
+++ b/manpages/de/lb_binary.de.1
@@ -3,7 +3,7 @@
 .\" This file was generated with po4a. Translate the source file.
 .\"
 .\"*******************************************************************
-.TH LIVE\-BUILD 1 2012\-08\-27 3.0~a58\-1 "Debian Live Project"
+.TH LIVE\-BUILD 1 2012\-09\-20 3.0~a58\-1 "Debian Live Project"
 
 .SH NAME
 \fBlb binary\fP \- Complete the binary stage
diff --git a/manpages/de/lb_bootstrap.de.1 b/manpages/de/lb_bootstrap.de.1
index bf5e399..65337c1 100644
--- a/manpages/de/lb_bootstrap.de.1
+++ b/manpages/de/lb_bootstrap.de.1
@@ -3,7 +3,7 @@
 .\" This file was generated with po4a. Translate the source file.
 .\"
 .\"*******************************************************************
-.TH LIVE\-BUILD 1 2012\-08\-27 3.0~a58\-1 "Debian Live Project"
+.TH LIVE\-BUILD 1 2012\-09\-20 3.0~a58\-1 "Debian Live Project"
 
 .SH NAME
 \fBlb bootstrap\fP \- Complete the bootstrap stage
diff --git a/manpages/de/lb_build.de.1 b/manpages/de/lb_build.de.1
index 1f5459b..0aaeadf 100644
--- a/manpages/de/lb_build.de.1
+++ b/manpages/de/lb_build.de.1
@@ -3,7 +3,7 @@
 .\" This file was generated with po4a. Translate the source file.
 .\"
 .\"*******************************************************************
-.TH LIVE\-BUILD 1 2012\-08\-27 3.0~a58\-1 "Debian Live Project"
+.TH LIVE\-BUILD 1 2012\-09\-20 3.0~a58\-1 "Debian Live Project"
 
 .SH NAME
 \fBlb build\fP \- Complete the bootstrap, chroot, binary, and source stages
diff --git a/manpages/de/lb_chroot.de.1 b/manpages/de/lb_chroot.de.1
index 7c646d7..b3b2f0c 100644
--- a/manpages/de/lb_chroot.de.1
+++ b/manpages/de/lb_chroot.de.1
@@ -3,7 +3,7 @@
 .\" This file was generated with po4a. Translate the source file.
 .\"
 .\"*******************************************************************
-.TH LIVE\-BUILD 1 2012\-08\-27 3.0~a58\-1 "Debian Live Project"
+.TH LIVE\-BUILD 1 2012\-09\-20 3.0~a58\-1 "Debian Live Project"
 
 .SH NAME
 \fBlb chroot\fP \- Complete the chroot stage
diff --git a/manpages/de/lb_clean.de.1 b/manpages/de/lb_clean.de.1
index 03adf8d..c00822a 100644
--- a/manpages/de/lb_clean.de.1
+++ b/manpages/de/lb_clean.de.1
@@ -3,7 +3,7 @@
 .\" This file was generated with po4a. Translate the source file.
 .\"
 .\"*******************************************************************
-.TH LIVE\-BUILD 1 2012\-08\-27 3.0~a58\-1 "Debian Live Project"
+.TH LIVE\-BUILD 1 2012\-09\-20 3.0~a58\-1 "Debian Live Project"
 
 .SH NAME
 \fBlb clean\fP \- Clean build directory
diff --git a/manpages/de/lb_config.de.1 b/manpages/de/lb_config.de.1
index 96f6c87..1a54dbf 100644
--- a/manpages/de/lb_config.de.1
+++ b/manpages/de/lb_config.de.1
@@ -3,7 +3,7 @@
 .\" This file was generated with po4a. Translate the source file.
 .\"
 .\"*******************************************************************
-.TH LIVE\-BUILD 1 2012\-08\-27 3.0~a58\-1 "Debian Live Project"
+.TH LIVE\-BUILD 1 2012\-09\-20 3.0~a58\-1 "Debian Live Project"
 
 .SH NAME
 \fBlb config\fP \- Create config directory
@@ -146,7 +146,7 @@
 .br
   [\fB\-\-parent\-mirror\-chroot\-security\fP \fIURL\fP]
 .br
-  [\fB\-\-parent\-mirror\-chroot\-volatile\fP \fIURL\fP]
+  [\fB\-\-parent\-mirror\-chroot\-updates\fP \fIURL\fP]
 .br
   [\fB\-\-parent\-mirror\-chroot\-backports\fP \fIURL\fP]
 .br
@@ -154,7 +154,7 @@
 .br
   [\fB\-\-parent\-mirror\-binary\-security\fP \fIURL\fP]
 .br
-  [\fB\-\-parent\-mirror\-binary\-volatile\fP \fIURL\fP]
+  [\fB\-\-parent\-mirror\-binary\-updates\fP \fIURL\fP]
 .br
   [\fB\-\-parent\-mirror\-binary\-backports\fP \fIURL\fP]
 .br
@@ -166,7 +166,7 @@
 .br
   [\fB\-\-mirror\-chroot\-security\fP \fIURL\fP]
 .br
-  [\fB\-\-mirror\-chroot\-volatile\fP \fIURL\fP]
+  [\fB\-\-mirror\-chroot\-updates\fP \fIURL\fP]
 .br
   [\fB\-\-mirror\-chroot\-backports\fP \fIURL\fP]
 .br
@@ -174,7 +174,7 @@
 .br
   [\fB\-\-mirror\-binary\-security\fP \fIURL\fP]
 .br
-  [\fB\-\-mirror\-binary\-volatile\fP \fIURL\fP]
+  [\fB\-\-mirror\-binary\-updates\fP \fIURL\fP]
 .br
   [\fB\-\-mirror\-binary\-backports\fP \fIURL\fP]
 .br
@@ -231,7 +231,7 @@
 .br
   [\fB\-\-hdd\-size \fP\fIMB\fP]
 .br
-  [\fB\-\-volatile\fP true|false]
+  [\fB\-\-updates\fP true|false]
 .br
   [\fB\-\-backports\fP true|false]
 .br
@@ -565,8 +565,8 @@ the value of \-\-parent\-mirror\-bootstrap.
 sets the location of the debian security package mirror that will be used to
 fetch the packages in order to build the live system. By default, this
 points to http://security.debian.org/debian/.
-.IP "\fB\-\-parent\-mirror\-chroot\-volatile\fP \fIURL\fP" 4
-sets the location of the debian volatile package mirror that will be used to
+.IP "\fB\-\-parent\-mirror\-chroot\-updates\fP \fIURL\fP" 4
+sets the location of the debian updates package mirror that will be used to
 fetch packages in order to build the live system. By default, this is set to
 the value of \-\-parent\-mirror\-chroot.
 .IP "\fB\-\-parent\-mirror\-chroot\-backports\fP \fIURL\fP" 4
@@ -583,8 +583,8 @@ default, 'http://http.debian.net/debian/' is used.
 sets the location of the debian security package mirror that should end up
 configured in the final image. By default, 'http://security.debian.org/' is
 used.
-.IP "\fB\-\-parent\-mirror\-binary\-volatile\fP \fIURL\fP" 4
-sets the location of the debian volatile package mirror that should end up
+.IP "\fB\-\-parent\-mirror\-binary\-updates\fP \fIURL\fP" 4
+sets the location of the debian updates package mirror that should end up
 configured in the final image. By default, the value of
 \-\-parent\-mirror\-binary is used.
 .IP "\fB\-\-parent\-mirror\-binary\-backports\fP \fIURL\fP" 4
@@ -608,8 +608,8 @@ default, this is set to the value of \-\-mirror\-bootstrap.
 sets the location of the debian security package mirror that will be used to
 fetch the packages of the derivative in order to build the live system. By
 default, this points to http://security.debian.org/debian/.
-.IP "\fB\-\-mirror\-chroot\-volatile\fP \fIURL\fP" 4
-sets the location of the debian volatile package mirror that will be used to
+.IP "\fB\-\-mirror\-chroot\-updates\fP \fIURL\fP" 4
+sets the location of the debian updates package mirror that will be used to
 fetch packages of the derivative in order to build the live system. By
 default, this is set to the value of \-\-mirror\-chroot.
 .IP "\fB\-\-mirror\-chroot\-backports\fP \fIURL\fP" 4
@@ -625,8 +625,8 @@ the image.
 .IP "\fB\-\-mirror\-binary\-security\fP \fIURL\fP" 4
 sets the location of the derivatives security package mirror that should end
 up configured in the final image.
-.IP "\fB\-\-mirror\-binary\-volatile\fP \fIURL\fP" 4
-sets the location of the derivatives volatile package mirror that should end
+.IP "\fB\-\-mirror\-binary\-updates\fP \fIURL\fP" 4
+sets the location of the derivatives updates package mirror that should end
 up configured in the final image.
 .IP "\fB\-\-mirror\-binary\-backports\fP \fIURL\fP" 4
 sets the location of the derivatives backports package mirror that should
@@ -752,8 +752,8 @@ bootloaders. By default, this is set to /usr/share/live/build/templates/.
 defines what size the hdd image should be. Note that although the default is
 set to 10000 (= 10GB), it will not need 10GB space on your harddisk as the
 files are created as sparse files.
-.IP "\fB\-\-volatile\fP true|false" 4
-defines if debian volatile package archives should be included in the image
+.IP "\fB\-\-updates\fP true|false" 4
+defines if debian updates package archives should be included in the image
 or not.
 .IP "\fB\-\-backports\fP true|false" 4
 defines if debian backports package archives should be included in the image
diff --git a/manpages/de/lb_source.de.1 b/manpages/de/lb_source.de.1
index df2670a..5e126f2 100644
--- a/manpages/de/lb_source.de.1
+++ b/manpages/de/lb_source.de.1
@@ -3,7 +3,7 @@
 .\" This file was generated with po4a. Translate the source file.
 .\"
 .\"*******************************************************************
-.TH LIVE\-BUILD 1 2012\-08\-27 3.0~a58\-1 "Debian Live Project"
+.TH LIVE\-BUILD 1 2012\-09\-20 3.0~a58\-1 "Debian Live Project"
 
 .SH NAME
 \fBlb source\fP \- Complete the source stage
diff --git a/manpages/de/lb_testroot.de.1 b/manpages/de/lb_testroot.de.1
index b2489f5..4c7e003 100644
--- a/manpages/de/lb_testroot.de.1
+++ b/manpages/de/lb_testroot.de.1
@@ -3,7 +3,7 @@
 .\" This file was generated with po4a. Translate the source file.
 .\"
 .\"*******************************************************************
-.TH LIVE\-BUILD 1 2012\-08\-27 3.0~a58\-1 "Debian Live Project"
+.TH LIVE\-BUILD 1 2012\-09\-20 3.0~a58\-1 "Debian Live Project"
 
 .SH NAME
 \fBlb testroot\fP \- Ensure that a system is built as root
diff --git a/manpages/de/live-build.de.7 b/manpages/de/live-build.de.7
index 660ec23..c9cd380 100644
--- a/manpages/de/live-build.de.7
+++ b/manpages/de/live-build.de.7
@@ -3,7 +3,7 @@
 .\" This file was generated with po4a. Translate the source file.
 .\"
 .\"*******************************************************************
-.TH LIVE\-BUILD 7 2012\-08\-27 3.0~a58\-1 "Debian Live Project"
+.TH LIVE\-BUILD 7 2012\-09\-20 3.0~a58\-1 "Debian Live Project"
 
 .SH NAME
 \fBlive\-build\fP \- the Debian Live tool suite
diff --git a/manpages/en/lb.1 b/manpages/en/lb.1
index ea76591..0c2d492 100644
--- a/manpages/en/lb.1
+++ b/manpages/en/lb.1
@@ -1,4 +1,4 @@
-.TH LIVE\-BUILD 1 2012\-08\-27 3.0~a58-1 "Debian Live Project"
+.TH LIVE\-BUILD 1 2012\-09\-20 3.0~a58-1 "Debian Live Project"
 
 .SH NAME
 \fBlb\fR \- wrapper for live\-build programs
diff --git a/manpages/en/lb_binary.1 b/manpages/en/lb_binary.1
index f934100..0b4b7d4 100644
--- a/manpages/en/lb_binary.1
+++ b/manpages/en/lb_binary.1
@@ -1,4 +1,4 @@
-.TH LIVE\-BUILD 1 2012\-08\-27 3.0~a58-1 "Debian Live Project"
+.TH LIVE\-BUILD 1 2012\-09\-20 3.0~a58-1 "Debian Live Project"
 
 .SH NAME
 \fBlb binary\fR \- Complete the binary stage
diff --git a/manpages/en/lb_bootstrap.1 b/manpages/en/lb_bootstrap.1
index 7580f6c..b9d2247 100644
--- a/manpages/en/lb_bootstrap.1
+++ b/manpages/en/lb_bootstrap.1
@@ -1,4 +1,4 @@
-.TH LIVE\-BUILD 1 2012\-08\-27 3.0~a58-1 "Debian Live Project"
+.TH LIVE\-BUILD 1 2012\-09\-20 3.0~a58-1 "Debian Live Project"
 
 .SH NAME
 \fBlb bootstrap\fR \- Complete the bootstrap stage
diff --git a/manpages/en/lb_build.1 b/manpages/en/lb_build.1
index 16db860..97ec27e 100644
--- a/manpages/en/lb_build.1
+++ b/manpages/en/lb_build.1
@@ -1,4 +1,4 @@
-.TH LIVE\-BUILD 1 2012\-08\-27 3.0~a58-1 "Debian Live Project"
+.TH LIVE\-BUILD 1 2012\-09\-20 3.0~a58-1 "Debian Live Project"
 
 .SH NAME
 \fBlb build\fR \- Complete the bootstrap, chroot, binary, and source stages
diff --git a/manpages/en/lb_chroot.1 b/manpages/en/lb_chroot.1
index 69c4cbc..9c87574 100644
--- a/manpages/en/lb_chroot.1
+++ b/manpages/en/lb_chroot.1
@@ -1,4 +1,4 @@
-.TH LIVE\-BUILD 1 2012\-08\-27 3.0~a58-1 "Debian Live Project"
+.TH LIVE\-BUILD 1 2012\-09\-20 3.0~a58-1 "Debian Live Project"
 
 .SH NAME
 \fBlb chroot\fR \- Complete the chroot stage
diff --git a/manpages/en/lb_clean.1 b/manpages/en/lb_clean.1
index aba47ea..9b6afb2 100644
--- a/manpages/en/lb_clean.1
+++ b/manpages/en/lb_clean.1
@@ -1,4 +1,4 @@
-.TH LIVE\-BUILD 1 2012\-08\-27 3.0~a58-1 "Debian Live Project"
+.TH LIVE\-BUILD 1 2012\-09\-20 3.0~a58-1 "Debian Live Project"
 
 .SH NAME
 \fBlb clean\fR \- Clean build directory
diff --git a/manpages/en/lb_config.1 b/manpages/en/lb_config.1
index 5785493..bf1c4d7 100644
--- a/manpages/en/lb_config.1
+++ b/manpages/en/lb_config.1
@@ -1,4 +1,4 @@
-.TH LIVE\-BUILD 1 2012\-08\-27 3.0~a58-1 "Debian Live Project"
+.TH LIVE\-BUILD 1 2012\-09\-20 3.0~a58-1 "Debian Live Project"
 
 .SH NAME
 \fBlb config\fR \- Create config directory
@@ -141,7 +141,7 @@
 .br
 	[\fB\-\-parent\-mirror\-chroot\-security\fR \fIURL\fR]
 .br
-	[\fB\-\-parent\-mirror\-chroot\-volatile\fR \fIURL\fR]
+	[\fB\-\-parent\-mirror\-chroot\-updates\fR \fIURL\fR]
 .br
 	[\fB\-\-parent\-mirror\-chroot\-backports\fR \fIURL\fR]
 .br
@@ -149,7 +149,7 @@
 .br
 	[\fB\-\-parent\-mirror\-binary\-security\fR \fIURL\fR]
 .br
-	[\fB\-\-parent\-mirror\-binary\-volatile\fR \fIURL\fR]
+	[\fB\-\-parent\-mirror\-binary\-updates\fR \fIURL\fR]
 .br
 	[\fB\-\-parent\-mirror\-binary\-backports\fR \fIURL\fR]
 .br
@@ -161,7 +161,7 @@
 .br
 	[\fB\-\-mirror\-chroot\-security\fR \fIURL\fR]
 .br
-	[\fB\-\-mirror\-chroot\-volatile\fR \fIURL\fR]
+	[\fB\-\-mirror\-chroot\-updates\fR \fIURL\fR]
 .br
 	[\fB\-\-mirror\-chroot\-backports\fR \fIURL\fR]
 .br
@@ -169,7 +169,7 @@
 .br
 	[\fB\-\-mirror\-binary\-security\fR \fIURL\fR]
 .br
-	[\fB\-\-mirror\-binary\-volatile\fR \fIURL\fR]
+	[\fB\-\-mirror\-binary\-updates\fR \fIURL\fR]
 .br
 	[\fB\-\-mirror\-binary\-backports\fR \fIURL\fR]
 .br
@@ -225,7 +225,7 @@
 .br
 	[\fB\-\-hdd\-size \fIMB\fR]
 .br
-	[\fB\-\-volatile\fR true|false]
+	[\fB\-\-updates\fR true|false]
 .br
 	[\fB\-\-backports\fR true|false]
 .br
@@ -375,16 +375,16 @@ sets the location of the debian package mirror that should be used to bootstrap
 sets the location of the debian package mirror that will be used to fetch the packages in order to build the live system. By default, this is set to the value of \-\-parent\-mirror\-bootstrap.
 .IP "\fB\-\-parent\-mirror\-chroot\-security\fR \fIURL\fR" 4
 sets the location of the debian security package mirror that will be used to fetch the packages in order to build the live system. By default, this points to http://security.debian.org/debian/.
-.IP "\fB\-\-parent\-mirror\-chroot\-volatile\fR \fIURL\fR" 4
-sets the location of the debian volatile package mirror that will be used to fetch packages in order to build the live system. By default, this is set to the value of \-\-parent\-mirror\-chroot.
+.IP "\fB\-\-parent\-mirror\-chroot\-updates\fR \fIURL\fR" 4
+sets the location of the debian updates package mirror that will be used to fetch packages in order to build the live system. By default, this is set to the value of \-\-parent\-mirror\-chroot.
 .IP "\fB\-\-parent\-mirror\-chroot\-backports\fR \fIURL\fR" 4
 sets the location of the debian backports package mirror that will be used to fetch packages in order to build the live system. By default, this points to http://backports.debian.org/debian-backports/.
 .IP "\fB\-\-parent\-mirror\-binary\fR \fIURL\fR" 4
 sets the location of the debian package mirror that should end up configured in the final image and which is the one a user would see and use. This has not necessarily to be the same that is used to build the image, e.g. if you use a local mirror but want to have an official mirror in the image. By default, 'http://http.debian.net/debian/' is used.
 .IP "\fB\-\-parent\-mirror\-binary\-security\fR \fIURL\fR" 4
 sets the location of the debian security package mirror that should end up configured in the final image. By default, 'http://security.debian.org/' is used.
-.IP "\fB\-\-parent\-mirror\-binary\-volatile\fR \fIURL\fR" 4
-sets the location of the debian volatile package mirror that should end up configured in the final image. By default, the value of \-\-parent\-mirror\-binary is used.
+.IP "\fB\-\-parent\-mirror\-binary\-updates\fR \fIURL\fR" 4
+sets the location of the debian updates package mirror that should end up configured in the final image. By default, the value of \-\-parent\-mirror\-binary is used.
 .IP "\fB\-\-parent\-mirror\-binary\-backports\fR \fIURL\fR" 4
 sets the location of the debian backports package mirror that should end up configured in the final image. By default, 'http://backports.debian.org/debian-backports/' is used.
 .IP "\fB\-\-parent\-mirror\-debian\-installer\fR \fIURL\fR" 4
@@ -395,16 +395,16 @@ sets the location of the debian package mirror that should be used to bootstrap
 sets the location of the debian package mirror that will be used to fetch the packages of the derivative in order to build the live system. By default, this is set to the value of \-\-mirror\-bootstrap.
 .IP "\fB\-\-mirror\-chroot\-security\fR \fIURL\fR" 4
 sets the location of the debian security package mirror that will be used to fetch the packages of the derivative in order to build the live system. By default, this points to http://security.debian.org/debian/.
-.IP "\fB\-\-mirror\-chroot\-volatile\fR \fIURL\fR" 4
-sets the location of the debian volatile package mirror that will be used to fetch packages of the derivative in order to build the live system. By default, this is set to the value of \-\-mirror\-chroot.
+.IP "\fB\-\-mirror\-chroot\-updates\fR \fIURL\fR" 4
+sets the location of the debian updates package mirror that will be used to fetch packages of the derivative in order to build the live system. By default, this is set to the value of \-\-mirror\-chroot.
 .IP "\fB\-\-mirror\-chroot\-backports\fR \fIURL\fR" 4
 sets the location of the debian backports package mirror that will be used to fetch packages of the derivative in order to build the live system. By default, this points to http://backports.debian.org/debian-backports/.
 .IP "\fB\-\-mirror\-binary\fR \fIURL\fR" 4
 sets the location of the derivative package mirror that should end up configured in the final image and which is the one a user would see and use. This has not necessarily to be the same that is used to build the image, e.g. if you use a local mirror but want to have an official mirror in the image.
 .IP "\fB\-\-mirror\-binary\-security\fR \fIURL\fR" 4
 sets the location of the derivatives security package mirror that should end up configured in the final image.
-.IP "\fB\-\-mirror\-binary\-volatile\fR \fIURL\fR" 4
-sets the location of the derivatives volatile package mirror that should end up configured in the final image.
+.IP "\fB\-\-mirror\-binary\-updates\fR \fIURL\fR" 4
+sets the location of the derivatives updates package mirror that should end up configured in the final image.
 .IP "\fB\-\-mirror\-binary\-backports\fR \fIURL\fR" 4
 sets the location of the derivatives backports package mirror that should end up configured in the final image.
 .IP "\fB\-\-mirror\-debian\-installer\fR \fIURL\fR" 4
@@ -474,8 +474,8 @@ selects which program is used to install tasks. By default, this is set to tasks
 sets the path to the templates that live\-build is going to use, e.g. for bootloaders. By default, this is set to /usr/share/live/build/templates/.
 .IP "\fB\-\-hdd\-size\fR MB" 4
 defines what size the hdd image should be. Note that although the default is set to 10000 (= 10GB), it will not need 10GB space on your harddisk as the files are created as sparse files.
-.IP "\fB\-\-volatile\fR true|false" 4
-defines if debian volatile package archives should be included in the image or not.
+.IP "\fB\-\-updates\fR true|false" 4
+defines if debian updates package archives should be included in the image or not.
 .IP "\fB\-\-backports\fR true|false" 4
 defines if debian backports package archives should be included in the image or not.
 .IP "\fB\-\-exposed\-root\fR true|false" 4
diff --git a/manpages/en/lb_source.1 b/manpages/en/lb_source.1
index e97b739..203e260 100644
--- a/manpages/en/lb_source.1
+++ b/manpages/en/lb_source.1
@@ -1,4 +1,4 @@
-.TH LIVE\-BUILD 1 2012\-08\-27 3.0~a58-1 "Debian Live Project"
+.TH LIVE\-BUILD 1 2012\-09\-20 3.0~a58-1 "Debian Live Project"
 
 .SH NAME
 \fBlb source\fR \- Complete the source stage
diff --git a/manpages/en/lb_testroot.1 b/manpages/en/lb_testroot.1
index b1c0dac..6d52997 100644
--- a/manpages/en/lb_testroot.1
+++ b/manpages/en/lb_testroot.1
@@ -1,4 +1,4 @@
-.TH LIVE\-BUILD 1 2012\-08\-27 3.0~a58-1 "Debian Live Project"
+.TH LIVE\-BUILD 1 2012\-09\-20 3.0~a58-1 "Debian Live Project"
 
 .SH NAME
 \fBlb testroot\fR \- Ensure that a system is built as root
diff --git a/manpages/en/live-build.7 b/manpages/en/live-build.7
index 8b957f1..574e636 100644
--- a/manpages/en/live-build.7
+++ b/manpages/en/live-build.7
@@ -1,4 +1,4 @@
-.TH LIVE\-BUILD 7 2012\-08\-27 3.0~a58-1 "Debian Live Project"
+.TH LIVE\-BUILD 7 2012\-09\-20 3.0~a58-1 "Debian Live Project"
 
 .SH NAME
 \fBlive\-build\fR \- the Debian Live tool suite
diff --git a/manpages/po/de/lb.1.po b/manpages/po/de/lb.1.po
index 70bdc62..c78f66a 100644
--- a/manpages/po/de/lb.1.po
+++ b/manpages/po/de/lb.1.po
@@ -6,7 +6,7 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: live-build VERSION\n"
-"POT-Creation-Date: 2012-08-27 16:32+0300\n"
+"POT-Creation-Date: 2012-09-20 16:51+0300\n"
 "PO-Revision-Date: 2012-08-02 18:55+0300\n"
 "Last-Translator: Automatically generated\n"
 "Language-Team: none\n"
@@ -29,7 +29,7 @@ msgstr ""
 #: en/lb_chroot.1:1 en/lb_clean.1:1 en/lb_config.1:1 en/lb_source.1:1
 #: en/lb_testroot.1:1 en/live-build.7:1
 #, no-wrap
-msgid "2012-08-27"
+msgid "2012-09-20"
 msgstr ""
 
 #. type: TH
diff --git a/manpages/po/de/lb_binary.1.po b/manpages/po/de/lb_binary.1.po
index 9205f5a..03a6378 100644
--- a/manpages/po/de/lb_binary.1.po
+++ b/manpages/po/de/lb_binary.1.po
@@ -6,7 +6,7 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: live-build VERSION\n"
-"POT-Creation-Date: 2012-08-27 16:32+0300\n"
+"POT-Creation-Date: 2012-09-20 16:51+0300\n"
 "PO-Revision-Date: 2012-08-02 18:55+0300\n"
 "Last-Translator: Automatically generated\n"
 "Language-Team: none\n"
@@ -29,7 +29,7 @@ msgstr ""
 #: en/lb_chroot.1:1 en/lb_clean.1:1 en/lb_config.1:1 en/lb_source.1:1
 #: en/lb_testroot.1:1 en/live-build.7:1
 #, no-wrap
-msgid "2012-08-27"
+msgid "2012-09-20"
 msgstr ""
 
 #. type: TH
diff --git a/manpages/po/de/lb_bootstrap.1.po b/manpages/po/de/lb_bootstrap.1.po
index b2e8c04..b1182ea 100644
--- a/manpages/po/de/lb_bootstrap.1.po
+++ b/manpages/po/de/lb_bootstrap.1.po
@@ -6,7 +6,7 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: live-build VERSION\n"
-"POT-Creation-Date: 2012-08-27 16:32+0300\n"
+"POT-Creation-Date: 2012-09-20 16:51+0300\n"
 "PO-Revision-Date: 2012-08-02 18:55+0300\n"
 "Last-Translator: Automatically generated\n"
 "Language-Team: none\n"
@@ -29,7 +29,7 @@ msgstr ""
 #: en/lb_chroot.1:1 en/lb_clean.1:1 en/lb_config.1:1 en/lb_source.1:1
 #: en/lb_testroot.1:1 en/live-build.7:1
 #, no-wrap
-msgid "2012-08-27"
+msgid "2012-09-20"
 msgstr ""
 
 #. type: TH
diff --git a/manpages/po/de/lb_build.1.po b/manpages/po/de/lb_build.1.po
index b1c6c80..8744614 100644
--- a/manpages/po/de/lb_build.1.po
+++ b/manpages/po/de/lb_build.1.po
@@ -6,7 +6,7 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: live-build VERSION\n"
-"POT-Creation-Date: 2012-08-27 16:32+0300\n"
+"POT-Creation-Date: 2012-09-20 16:51+0300\n"
 "PO-Revision-Date: 2012-08-02 18:55+0300\n"
 "Last-Translator: Automatically generated\n"
 "Language-Team: none\n"
@@ -29,7 +29,7 @@ msgstr ""
 #: en/lb_chroot.1:1 en/lb_clean.1:1 en/lb_config.1:1 en/lb_source.1:1
 #: en/lb_testroot.1:1 en/live-build.7:1
 #, no-wrap
-msgid "2012-08-27"
+msgid "2012-09-20"
 msgstr ""
 
 #. type: TH
diff --git a/manpages/po/de/lb_chroot.1.po b/manpages/po/de/lb_chroot.1.po
index 87f3ad3..2c00d41 100644
--- a/manpages/po/de/lb_chroot.1.po
+++ b/manpages/po/de/lb_chroot.1.po
@@ -6,7 +6,7 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: live-build VERSION\n"
-"POT-Creation-Date: 2012-08-27 16:32+0300\n"
+"POT-Creation-Date: 2012-09-20 16:51+0300\n"
 "PO-Revision-Date: 2012-08-02 18:55+0300\n"
 "Last-Translator: Automatically generated\n"
 "Language-Team: none\n"
@@ -29,7 +29,7 @@ msgstr ""
 #: en/lb_chroot.1:1 en/lb_clean.1:1 en/lb_config.1:1 en/lb_source.1:1
 #: en/lb_testroot.1:1 en/live-build.7:1
 #, no-wrap
-msgid "2012-08-27"
+msgid "2012-09-20"
 msgstr ""
 
 #. type: TH
diff --git a/manpages/po/de/lb_clean.1.po b/manpages/po/de/lb_clean.1.po
index 64354e5..16fd74a 100644
--- a/manpages/po/de/lb_clean.1.po
+++ b/manpages/po/de/lb_clean.1.po
@@ -6,7 +6,7 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: live-build VERSION\n"
-"POT-Creation-Date: 2012-08-27 16:32+0300\n"
+"POT-Creation-Date: 2012-09-20 16:51+0300\n"
 "PO-Revision-Date: 2012-08-02 18:55+0300\n"
 "Last-Translator: Automatically generated\n"
 "Language-Team: none\n"
@@ -29,7 +29,7 @@ msgstr ""
 #: en/lb_chroot.1:1 en/lb_clean.1:1 en/lb_config.1:1 en/lb_source.1:1
 #: en/lb_testroot.1:1 en/live-build.7:1
 #, no-wrap
-msgid "2012-08-27"
+msgid "2012-09-20"
 msgstr ""
 
 #. type: TH
diff --git a/manpages/po/de/lb_config.1.po b/manpages/po/de/lb_config.1.po
index 055efcf..7ac41b5 100644
--- a/manpages/po/de/lb_config.1.po
+++ b/manpages/po/de/lb_config.1.po
@@ -6,7 +6,7 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: live-build VERSION\n"
-"POT-Creation-Date: 2012-08-27 16:32+0300\n"
+"POT-Creation-Date: 2012-09-20 16:51+0300\n"
 "PO-Revision-Date: 2012-08-02 18:55+0300\n"
 "Last-Translator: Automatically generated\n"
 "Language-Team: none\n"
@@ -29,7 +29,7 @@ msgstr ""
 #: en/lb_chroot.1:1 en/lb_clean.1:1 en/lb_config.1:1 en/lb_source.1:1
 #: en/lb_testroot.1:1 en/live-build.7:1
 #, no-wrap
-msgid "2012-08-27"
+msgid "2012-09-20"
 msgstr ""
 
 #. type: TH
@@ -513,7 +513,7 @@ msgstr ""
 
 #. type: Plain text
 #: en/lb_config.1:145
-msgid "  [B<--parent-mirror-chroot-volatile> I<URL>]"
+msgid "  [B<--parent-mirror-chroot-updates> I<URL>]"
 msgstr ""
 
 #. type: Plain text
@@ -533,7 +533,7 @@ msgstr ""
 
 #. type: Plain text
 #: en/lb_config.1:153
-msgid "  [B<--parent-mirror-binary-volatile> I<URL>]"
+msgid "  [B<--parent-mirror-binary-updates> I<URL>]"
 msgstr ""
 
 #. type: Plain text
@@ -563,7 +563,7 @@ msgstr ""
 
 #. type: Plain text
 #: en/lb_config.1:165
-msgid "  [B<--mirror-chroot-volatile> I<URL>]"
+msgid "  [B<--mirror-chroot-updates> I<URL>]"
 msgstr ""
 
 #. type: Plain text
@@ -583,7 +583,7 @@ msgstr ""
 
 #. type: Plain text
 #: en/lb_config.1:173
-msgid "  [B<--mirror-binary-volatile> I<URL>]"
+msgid "  [B<--mirror-binary-updates> I<URL>]"
 msgstr ""
 
 #. type: Plain text
@@ -725,7 +725,7 @@ msgstr ""
 
 #. type: Plain text
 #: en/lb_config.1:229
-msgid "  [B<--volatile> true|false]"
+msgid "  [B<--updates> true|false]"
 msgstr ""
 
 #. type: Plain text
@@ -1711,13 +1711,13 @@ msgstr ""
 #. type: IP
 #: en/lb_config.1:378
 #, no-wrap
-msgid "B<--parent-mirror-chroot-volatile> I<URL>"
+msgid "B<--parent-mirror-chroot-updates> I<URL>"
 msgstr ""
 
 #. type: Plain text
 #: en/lb_config.1:380
 msgid ""
-"sets the location of the debian volatile package mirror that will be used to "
+"sets the location of the debian updates package mirror that will be used to "
 "fetch packages in order to build the live system. By default, this is set to "
 "the value of --parent-mirror-chroot."
 msgstr ""
@@ -1769,13 +1769,13 @@ msgstr ""
 #. type: IP
 #: en/lb_config.1:386
 #, no-wrap
-msgid "B<--parent-mirror-binary-volatile> I<URL>"
+msgid "B<--parent-mirror-binary-updates> I<URL>"
 msgstr ""
 
 #. type: Plain text
 #: en/lb_config.1:388
 msgid ""
-"sets the location of the debian volatile package mirror that should end up "
+"sets the location of the debian updates package mirror that should end up "
 "configured in the final image. By default, the value of --parent-mirror-"
 "binary is used."
 msgstr ""
@@ -1853,13 +1853,13 @@ msgstr ""
 #. type: IP
 #: en/lb_config.1:398
 #, no-wrap
-msgid "B<--mirror-chroot-volatile> I<URL>"
+msgid "B<--mirror-chroot-updates> I<URL>"
 msgstr ""
 
 #. type: Plain text
 #: en/lb_config.1:400
 msgid ""
-"sets the location of the debian volatile package mirror that will be used to "
+"sets the location of the debian updates package mirror that will be used to "
 "fetch packages of the derivative in order to build the live system. By "
 "default, this is set to the value of --mirror-chroot."
 msgstr ""
@@ -1910,13 +1910,13 @@ msgstr ""
 #. type: IP
 #: en/lb_config.1:406
 #, no-wrap
-msgid "B<--mirror-binary-volatile> I<URL>"
+msgid "B<--mirror-binary-updates> I<URL>"
 msgstr ""
 
 #. type: Plain text
 #: en/lb_config.1:408
 msgid ""
-"sets the location of the derivatives volatile package mirror that should end "
+"sets the location of the derivatives updates package mirror that should end "
 "up configured in the final image."
 msgstr ""
 
@@ -2362,13 +2362,13 @@ msgstr ""
 #. type: IP
 #: en/lb_config.1:477
 #, no-wrap
-msgid "B<--volatile> true|false"
+msgid "B<--updates> true|false"
 msgstr ""
 
 #. type: Plain text
 #: en/lb_config.1:479
 msgid ""
-"defines if debian volatile package archives should be included in the image "
+"defines if debian updates package archives should be included in the image "
 "or not."
 msgstr ""
 
diff --git a/manpages/po/de/lb_source.1.po b/manpages/po/de/lb_source.1.po
index 3ef00e8..7bd5bd2 100644
--- a/manpages/po/de/lb_source.1.po
+++ b/manpages/po/de/lb_source.1.po
@@ -6,7 +6,7 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: live-build VERSION\n"
-"POT-Creation-Date: 2012-08-27 16:32+0300\n"
+"POT-Creation-Date: 2012-09-20 16:51+0300\n"
 "PO-Revision-Date: 2012-08-02 18:55+0300\n"
 "Last-Translator: Automatically generated\n"
 "Language-Team: none\n"
@@ -29,7 +29,7 @@ msgstr ""
 #: en/lb_chroot.1:1 en/lb_clean.1:1 en/lb_config.1:1 en/lb_source.1:1
 #: en/lb_testroot.1:1 en/live-build.7:1
 #, no-wrap
-msgid "2012-08-27"
+msgid "2012-09-20"
 msgstr ""
 
 #. type: TH
diff --git a/manpages/po/de/lb_testroot.1.po b/manpages/po/de/lb_testroot.1.po
index 249df77..d8a0ccc 100644
--- a/manpages/po/de/lb_testroot.1.po
+++ b/manpages/po/de/lb_testroot.1.po
@@ -6,7 +6,7 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: live-build VERSION\n"
-"POT-Creation-Date: 2012-08-27 16:32+0300\n"
+"POT-Creation-Date: 2012-09-20 16:51+0300\n"
 "PO-Revision-Date: 2012-08-02 18:55+0300\n"
 "Last-Translator: Automatically generated\n"
 "Language-Team: none\n"
@@ -29,7 +29,7 @@ msgstr ""
 #: en/lb_chroot.1:1 en/lb_clean.1:1 en/lb_config.1:1 en/lb_source.1:1
 #: en/lb_testroot.1:1 en/live-build.7:1
 #, no-wrap
-msgid "2012-08-27"
+msgid "2012-09-20"
 msgstr ""
 
 #. type: TH
diff --git a/manpages/po/de/live-build.7.po b/manpages/po/de/live-build.7.po
index e0b2926..51f4d23 100644
--- a/manpages/po/de/live-build.7.po
+++ b/manpages/po/de/live-build.7.po
@@ -6,7 +6,7 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: live-build VERSION\n"
-"POT-Creation-Date: 2012-08-27 16:32+0300\n"
+"POT-Creation-Date: 2012-09-20 16:51+0300\n"
 "PO-Revision-Date: 2012-08-02 18:55+0300\n"
 "Last-Translator: Automatically generated\n"
 "Language-Team: none\n"
@@ -29,7 +29,7 @@ msgstr ""
 #: en/lb_chroot.1:1 en/lb_clean.1:1 en/lb_config.1:1 en/lb_source.1:1
 #: en/lb_testroot.1:1 en/live-build.7:1
 #, no-wrap
-msgid "2012-08-27"
+msgid "2012-09-20"
 msgstr ""
 
 #. type: TH
diff --git a/manpages/pot/lb.1.pot b/manpages/pot/lb.1.pot
index f6da563..e2d05ad 100644
--- a/manpages/pot/lb.1.pot
+++ b/manpages/pot/lb.1.pot
@@ -7,7 +7,7 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: live-build VERSION\n"
-"POT-Creation-Date: 2012-08-27 16:32+0300\n"
+"POT-Creation-Date: 2012-09-20 16:51+0300\n"
 "PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
 "Last-Translator: FULL NAME <EMAIL at ADDRESS>\n"
 "Language-Team: LANGUAGE <LL at li.org>\n"
@@ -29,7 +29,7 @@ msgstr ""
 #: en/lb_chroot.1:1 en/lb_clean.1:1 en/lb_config.1:1 en/lb_source.1:1
 #: en/lb_testroot.1:1 en/live-build.7:1
 #, no-wrap
-msgid "2012-08-27"
+msgid "2012-09-20"
 msgstr ""
 
 #. type: TH
diff --git a/manpages/pot/lb_binary.1.pot b/manpages/pot/lb_binary.1.pot
index 103e975..3c59f4d 100644
--- a/manpages/pot/lb_binary.1.pot
+++ b/manpages/pot/lb_binary.1.pot
@@ -7,7 +7,7 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: live-build VERSION\n"
-"POT-Creation-Date: 2012-08-27 16:32+0300\n"
+"POT-Creation-Date: 2012-09-20 16:51+0300\n"
 "PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
 "Last-Translator: FULL NAME <EMAIL at ADDRESS>\n"
 "Language-Team: LANGUAGE <LL at li.org>\n"
@@ -29,7 +29,7 @@ msgstr ""
 #: en/lb_chroot.1:1 en/lb_clean.1:1 en/lb_config.1:1 en/lb_source.1:1
 #: en/lb_testroot.1:1 en/live-build.7:1
 #, no-wrap
-msgid "2012-08-27"
+msgid "2012-09-20"
 msgstr ""
 
 #. type: TH
diff --git a/manpages/pot/lb_bootstrap.1.pot b/manpages/pot/lb_bootstrap.1.pot
index 0bf59b0..59c8df4 100644
--- a/manpages/pot/lb_bootstrap.1.pot
+++ b/manpages/pot/lb_bootstrap.1.pot
@@ -7,7 +7,7 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: live-build VERSION\n"
-"POT-Creation-Date: 2012-08-27 16:32+0300\n"
+"POT-Creation-Date: 2012-09-20 16:51+0300\n"
 "PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
 "Last-Translator: FULL NAME <EMAIL at ADDRESS>\n"
 "Language-Team: LANGUAGE <LL at li.org>\n"
@@ -29,7 +29,7 @@ msgstr ""
 #: en/lb_chroot.1:1 en/lb_clean.1:1 en/lb_config.1:1 en/lb_source.1:1
 #: en/lb_testroot.1:1 en/live-build.7:1
 #, no-wrap
-msgid "2012-08-27"
+msgid "2012-09-20"
 msgstr ""
 
 #. type: TH
diff --git a/manpages/pot/lb_build.1.pot b/manpages/pot/lb_build.1.pot
index cbd9105..e17f5cb 100644
--- a/manpages/pot/lb_build.1.pot
+++ b/manpages/pot/lb_build.1.pot
@@ -7,7 +7,7 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: live-build VERSION\n"
-"POT-Creation-Date: 2012-08-27 16:32+0300\n"
+"POT-Creation-Date: 2012-09-20 16:51+0300\n"
 "PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
 "Last-Translator: FULL NAME <EMAIL at ADDRESS>\n"
 "Language-Team: LANGUAGE <LL at li.org>\n"
@@ -29,7 +29,7 @@ msgstr ""
 #: en/lb_chroot.1:1 en/lb_clean.1:1 en/lb_config.1:1 en/lb_source.1:1
 #: en/lb_testroot.1:1 en/live-build.7:1
 #, no-wrap
-msgid "2012-08-27"
+msgid "2012-09-20"
 msgstr ""
 
 #. type: TH
diff --git a/manpages/pot/lb_chroot.1.pot b/manpages/pot/lb_chroot.1.pot
index 747d70d..060535c 100644
--- a/manpages/pot/lb_chroot.1.pot
+++ b/manpages/pot/lb_chroot.1.pot
@@ -7,7 +7,7 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: live-build VERSION\n"
-"POT-Creation-Date: 2012-08-27 16:32+0300\n"
+"POT-Creation-Date: 2012-09-20 16:51+0300\n"
 "PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
 "Last-Translator: FULL NAME <EMAIL at ADDRESS>\n"
 "Language-Team: LANGUAGE <LL at li.org>\n"
@@ -29,7 +29,7 @@ msgstr ""
 #: en/lb_chroot.1:1 en/lb_clean.1:1 en/lb_config.1:1 en/lb_source.1:1
 #: en/lb_testroot.1:1 en/live-build.7:1
 #, no-wrap
-msgid "2012-08-27"
+msgid "2012-09-20"
 msgstr ""
 
 #. type: TH
diff --git a/manpages/pot/lb_clean.1.pot b/manpages/pot/lb_clean.1.pot
index 0d9517a..667ca46 100644
--- a/manpages/pot/lb_clean.1.pot
+++ b/manpages/pot/lb_clean.1.pot
@@ -7,7 +7,7 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: live-build VERSION\n"
-"POT-Creation-Date: 2012-08-27 16:32+0300\n"
+"POT-Creation-Date: 2012-09-20 16:51+0300\n"
 "PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
 "Last-Translator: FULL NAME <EMAIL at ADDRESS>\n"
 "Language-Team: LANGUAGE <LL at li.org>\n"
@@ -29,7 +29,7 @@ msgstr ""
 #: en/lb_chroot.1:1 en/lb_clean.1:1 en/lb_config.1:1 en/lb_source.1:1
 #: en/lb_testroot.1:1 en/live-build.7:1
 #, no-wrap
-msgid "2012-08-27"
+msgid "2012-09-20"
 msgstr ""
 
 #. type: TH
diff --git a/manpages/pot/lb_config.1.pot b/manpages/pot/lb_config.1.pot
index e939137..0cf2615 100644
--- a/manpages/pot/lb_config.1.pot
+++ b/manpages/pot/lb_config.1.pot
@@ -7,7 +7,7 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: live-build VERSION\n"
-"POT-Creation-Date: 2012-08-27 16:32+0300\n"
+"POT-Creation-Date: 2012-09-20 16:51+0300\n"
 "PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
 "Last-Translator: FULL NAME <EMAIL at ADDRESS>\n"
 "Language-Team: LANGUAGE <LL at li.org>\n"
@@ -29,7 +29,7 @@ msgstr ""
 #: en/lb_chroot.1:1 en/lb_clean.1:1 en/lb_config.1:1 en/lb_source.1:1
 #: en/lb_testroot.1:1 en/live-build.7:1
 #, no-wrap
-msgid "2012-08-27"
+msgid "2012-09-20"
 msgstr ""
 
 #. type: TH
@@ -513,7 +513,7 @@ msgstr ""
 
 #. type: Plain text
 #: en/lb_config.1:145
-msgid "  [B<--parent-mirror-chroot-volatile> I<URL>]"
+msgid "  [B<--parent-mirror-chroot-updates> I<URL>]"
 msgstr ""
 
 #. type: Plain text
@@ -533,7 +533,7 @@ msgstr ""
 
 #. type: Plain text
 #: en/lb_config.1:153
-msgid "  [B<--parent-mirror-binary-volatile> I<URL>]"
+msgid "  [B<--parent-mirror-binary-updates> I<URL>]"
 msgstr ""
 
 #. type: Plain text
@@ -563,7 +563,7 @@ msgstr ""
 
 #. type: Plain text
 #: en/lb_config.1:165
-msgid "  [B<--mirror-chroot-volatile> I<URL>]"
+msgid "  [B<--mirror-chroot-updates> I<URL>]"
 msgstr ""
 
 #. type: Plain text
@@ -583,7 +583,7 @@ msgstr ""
 
 #. type: Plain text
 #: en/lb_config.1:173
-msgid "  [B<--mirror-binary-volatile> I<URL>]"
+msgid "  [B<--mirror-binary-updates> I<URL>]"
 msgstr ""
 
 #. type: Plain text
@@ -725,7 +725,7 @@ msgstr ""
 
 #. type: Plain text
 #: en/lb_config.1:229
-msgid "  [B<--volatile> true|false]"
+msgid "  [B<--updates> true|false]"
 msgstr ""
 
 #. type: Plain text
@@ -1711,13 +1711,13 @@ msgstr ""
 #. type: IP
 #: en/lb_config.1:378
 #, no-wrap
-msgid "B<--parent-mirror-chroot-volatile> I<URL>"
+msgid "B<--parent-mirror-chroot-updates> I<URL>"
 msgstr ""
 
 #. type: Plain text
 #: en/lb_config.1:380
 msgid ""
-"sets the location of the debian volatile package mirror that will be used to "
+"sets the location of the debian updates package mirror that will be used to "
 "fetch packages in order to build the live system. By default, this is set to "
 "the value of --parent-mirror-chroot."
 msgstr ""
@@ -1769,13 +1769,13 @@ msgstr ""
 #. type: IP
 #: en/lb_config.1:386
 #, no-wrap
-msgid "B<--parent-mirror-binary-volatile> I<URL>"
+msgid "B<--parent-mirror-binary-updates> I<URL>"
 msgstr ""
 
 #. type: Plain text
 #: en/lb_config.1:388
 msgid ""
-"sets the location of the debian volatile package mirror that should end up "
+"sets the location of the debian updates package mirror that should end up "
 "configured in the final image. By default, the value of --parent-mirror-"
 "binary is used."
 msgstr ""
@@ -1853,13 +1853,13 @@ msgstr ""
 #. type: IP
 #: en/lb_config.1:398
 #, no-wrap
-msgid "B<--mirror-chroot-volatile> I<URL>"
+msgid "B<--mirror-chroot-updates> I<URL>"
 msgstr ""
 
 #. type: Plain text
 #: en/lb_config.1:400
 msgid ""
-"sets the location of the debian volatile package mirror that will be used to "
+"sets the location of the debian updates package mirror that will be used to "
 "fetch packages of the derivative in order to build the live system. By "
 "default, this is set to the value of --mirror-chroot."
 msgstr ""
@@ -1910,13 +1910,13 @@ msgstr ""
 #. type: IP
 #: en/lb_config.1:406
 #, no-wrap
-msgid "B<--mirror-binary-volatile> I<URL>"
+msgid "B<--mirror-binary-updates> I<URL>"
 msgstr ""
 
 #. type: Plain text
 #: en/lb_config.1:408
 msgid ""
-"sets the location of the derivatives volatile package mirror that should end "
+"sets the location of the derivatives updates package mirror that should end "
 "up configured in the final image."
 msgstr ""
 
@@ -2362,13 +2362,13 @@ msgstr ""
 #. type: IP
 #: en/lb_config.1:477
 #, no-wrap
-msgid "B<--volatile> true|false"
+msgid "B<--updates> true|false"
 msgstr ""
 
 #. type: Plain text
 #: en/lb_config.1:479
 msgid ""
-"defines if debian volatile package archives should be included in the image "
+"defines if debian updates package archives should be included in the image "
 "or not."
 msgstr ""
 
diff --git a/manpages/pot/lb_source.1.pot b/manpages/pot/lb_source.1.pot
index 91c1f95..fba989e 100644
--- a/manpages/pot/lb_source.1.pot
+++ b/manpages/pot/lb_source.1.pot
@@ -7,7 +7,7 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: live-build VERSION\n"
-"POT-Creation-Date: 2012-08-27 16:32+0300\n"
+"POT-Creation-Date: 2012-09-20 16:51+0300\n"
 "PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
 "Last-Translator: FULL NAME <EMAIL at ADDRESS>\n"
 "Language-Team: LANGUAGE <LL at li.org>\n"
@@ -29,7 +29,7 @@ msgstr ""
 #: en/lb_chroot.1:1 en/lb_clean.1:1 en/lb_config.1:1 en/lb_source.1:1
 #: en/lb_testroot.1:1 en/live-build.7:1
 #, no-wrap
-msgid "2012-08-27"
+msgid "2012-09-20"
 msgstr ""
 
 #. type: TH
diff --git a/manpages/pot/lb_testroot.1.pot b/manpages/pot/lb_testroot.1.pot
index a55397e..18ce918 100644
--- a/manpages/pot/lb_testroot.1.pot
+++ b/manpages/pot/lb_testroot.1.pot
@@ -7,7 +7,7 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: live-build VERSION\n"
-"POT-Creation-Date: 2012-08-27 16:32+0300\n"
+"POT-Creation-Date: 2012-09-20 16:51+0300\n"
 "PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
 "Last-Translator: FULL NAME <EMAIL at ADDRESS>\n"
 "Language-Team: LANGUAGE <LL at li.org>\n"
@@ -29,7 +29,7 @@ msgstr ""
 #: en/lb_chroot.1:1 en/lb_clean.1:1 en/lb_config.1:1 en/lb_source.1:1
 #: en/lb_testroot.1:1 en/live-build.7:1
 #, no-wrap
-msgid "2012-08-27"
+msgid "2012-09-20"
 msgstr ""
 
 #. type: TH
diff --git a/manpages/pot/live-build.7.pot b/manpages/pot/live-build.7.pot
index ea7c718..a5406ff 100644
--- a/manpages/pot/live-build.7.pot
+++ b/manpages/pot/live-build.7.pot
@@ -7,7 +7,7 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: live-build VERSION\n"
-"POT-Creation-Date: 2012-08-27 16:32+0300\n"
+"POT-Creation-Date: 2012-09-20 16:51+0300\n"
 "PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
 "Last-Translator: FULL NAME <EMAIL at ADDRESS>\n"
 "Language-Team: LANGUAGE <LL at li.org>\n"
@@ -29,7 +29,7 @@ msgstr ""
 #: en/lb_chroot.1:1 en/lb_clean.1:1 en/lb_config.1:1 en/lb_source.1:1
 #: en/lb_testroot.1:1 en/live-build.7:1
 #, no-wrap
-msgid "2012-08-27"
+msgid "2012-09-20"
 msgstr ""
 
 #. type: TH
diff --git a/scripts/build/chroot_apt b/scripts/build/chroot_apt
index 2e1bce2..f3cf3a7 100755
--- a/scripts/build/chroot_apt
+++ b/scripts/build/chroot_apt
@@ -160,7 +160,7 @@ case "${1}" in
 						_ENABLE_DISTRIBUTIONS="${_ENABLE_DISTRIBUTIONS} ${_DISTRIBUTION}-security"
 					fi
 
-					if [ "${LB_VOLATILE}" = "true" ]
+					if [ "${LB_UPDATES}" = "true" ]
 					then
 						_ENABLE_DISTRIBUTIONS="${_ENABLE_DISTRIBUTIONS} ${_DISTRIBUTION}-updates"
 					fi
diff --git a/scripts/build/chroot_archives b/scripts/build/chroot_archives
index d0033d2..18b6862 100755
--- a/scripts/build/chroot_archives
+++ b/scripts/build/chroot_archives
@@ -142,22 +142,22 @@ EOF
 			esac
 		fi
 
-		if [ "${LB_VOLATILE}" = "true" ]
+		if [ "${LB_UPDATES}" = "true" ]
 		then
-			echo "deb ${LB_PARENT_MIRROR_CHROOT_VOLATILE} ${LB_PARENT_DISTRIBUTION}-updates ${LB_PARENT_ARCHIVE_AREAS}" >> chroot/etc/apt/${_PARENT_FILE}
+			echo "deb ${LB_PARENT_MIRROR_CHROOT_UPDATES} ${LB_PARENT_DISTRIBUTION}-updates ${LB_PARENT_ARCHIVE_AREAS}" >> chroot/etc/apt/${_PARENT_FILE}
 
 			if [ "${_PASS}" = "source" ] || [ "${LB_APT_SOURCE_ARCHIVES}" = "true" ]
 			then
-				echo "deb-src ${LB_PARENT_MIRROR_CHROOT_VOLATILE} ${LB_PARENT_DISTRIBUTION}-updates ${LB_PARENT_ARCHIVE_AREAS}" >> chroot/etc/apt/${_PARENT_FILE}
+				echo "deb-src ${LB_PARENT_MIRROR_CHROOT_UPDATES} ${LB_PARENT_DISTRIBUTION}-updates ${LB_PARENT_ARCHIVE_AREAS}" >> chroot/etc/apt/${_PARENT_FILE}
 			fi
 
-			if [ "${LB_DERIVATIVE}" = "true" ] && [ "${LB_MIRROR_CHROOT_VOLATILE}" != "none" ]
+			if [ "${LB_DERIVATIVE}" = "true" ] && [ "${LB_MIRROR_CHROOT_UPDATES}" != "none" ]
 			then
-				echo "deb ${LB_MIRROR_CHROOT_VOLATILE} ${_DISTRIBUTION}-updates ${LB_ARCHIVE_AREAS}" >> chroot/etc/apt/sources.list.d/${LB_MODE}.list
+				echo "deb ${LB_MIRROR_CHROOT_UPDATES} ${_DISTRIBUTION}-updates ${LB_ARCHIVE_AREAS}" >> chroot/etc/apt/sources.list.d/${LB_MODE}.list
 
 				if [ "${_PASS}" = "source" ] || [ "${LB_APT_SOURCE_ARCHIVES}" = "true" ]
 				then
-					echo "deb-src ${LB_MIRROR_CHROOT_VOLATILE} ${_DISTRIBUTION}-updates ${LB_ARCHIVE_AREAS}" >> chroot/etc/apt/sources.list.d/${LB_MODE}.list
+					echo "deb-src ${LB_MIRROR_CHROOT_UPDATES} ${_DISTRIBUTION}-updates ${LB_ARCHIVE_AREAS}" >> chroot/etc/apt/sources.list.d/${LB_MODE}.list
 				fi
 			fi
 		fi
@@ -710,22 +710,22 @@ EOF
 			esac
 		fi
 
-		if [ "${LB_VOLATILE}" = "true" ]
+		if [ "${LB_UPDATES}" = "true" ]
 		then
-			echo "deb ${LB_PARENT_MIRROR_BINARY_VOLATILE} ${LB_PARENT_DISTRIBUTION}-updates ${LB_PARENT_ARCHIVE_AREAS}" >> chroot/etc/apt/${_PARENT_FILE}
+			echo "deb ${LB_PARENT_MIRROR_BINARY_UPDATES} ${LB_PARENT_DISTRIBUTION}-updates ${LB_PARENT_ARCHIVE_AREAS}" >> chroot/etc/apt/${_PARENT_FILE}
 
 			if [ "${_PASS}" = "source" ] || [ "${LB_APT_SOURCE_ARCHIVES}" = "true" ]
 			then
-				echo "deb-src ${LB_PARENT_MIRROR_BINARY_VOLATILE} ${LB_PARENT_DISTRIBUTION}-updates ${LB_PARENT_ARCHIVE_AREAS}" >> chroot/etc/apt/${_PARENT_FILE}
+				echo "deb-src ${LB_PARENT_MIRROR_BINARY_UPDATES} ${LB_PARENT_DISTRIBUTION}-updates ${LB_PARENT_ARCHIVE_AREAS}" >> chroot/etc/apt/${_PARENT_FILE}
 			fi
 
-			if [ "${LB_DERIVATIVE}" = "true" ] && [ "${LB_MIRROR_BINARY_VOLATILE}" != "none" ]
+			if [ "${LB_DERIVATIVE}" = "true" ] && [ "${LB_MIRROR_BINARY_UPDATES}" != "none" ]
 			then
-				echo "deb ${LB_MIRROR_BINARY_VOLATILE} ${_DISTRIBUTION}-updates ${LB_ARCHIVE_AREAS}" >> chroot/etc/apt/sources.list.d/${LB_MODE}.list
+				echo "deb ${LB_MIRROR_BINARY_UPDATES} ${_DISTRIBUTION}-updates ${LB_ARCHIVE_AREAS}" >> chroot/etc/apt/sources.list.d/${LB_MODE}.list
 
 				if [ "${_PASS}" = "source" ] || [ "${LB_APT_SOURCE_ARCHIVES}" = "true" ]
 				then
-					echo "deb-src ${LB_MIRROR_BINARY_VOLATILE} ${_DISTRIBUTION}-updates ${LB_ARCHIVE_AREAS}" >> chroot/etc/apt/sources.list.d/${LB_MODE}.list
+					echo "deb-src ${LB_MIRROR_BINARY_UPDATES} ${_DISTRIBUTION}-updates ${LB_ARCHIVE_AREAS}" >> chroot/etc/apt/sources.list.d/${LB_MODE}.list
 				fi
 			fi
 		fi
diff --git a/scripts/build/config b/scripts/build/config
index 5dbb83c..27a6ba7 100755
--- a/scripts/build/config
+++ b/scripts/build/config
@@ -84,21 +84,21 @@ USAGE="${PROGRAM}   [--apt apt|aptitude]\n\
 \t    [-m|--parent-mirror-bootstrap URL]\n\
 \t    [--parent-mirror-chroot URL]\n\
 \t    [--parent-mirror-chroot-security URL]\n\
-\t    [--parent-mirror-chroot-volatile URL]\n\
+\t    [--parent-mirror-chroot-updates URL]\n\
 \t    [--parent-mirror-chroot-backports URL]\n\
 \t    [--parent-mirror-binary URL]\n\
 \t    [--parent-mirror-binary-security URL]\n\
-\t    [--parent-mirror-binary-volatile URL]\n\
+\t    [--parent-mirror-binary-updates URL]\n\
 \t    [--parent-mirror-binary-backports URL]\n\
 \t    [--parent-mirror-debian-installer URL]\n\
 \t    [--mirror-bootstrap URL]\n\
 \t    [--mirror-chroot URL]\n\
 \t    [--mirror-chroot-security URL]\n\
-\t    [--mirror-chroot-volatile URL]\n\
+\t    [--mirror-chroot-updates URL]\n\
 \t    [--mirror-chroot-backports URL]\n\
 \t    [--mirror-binary URL]\n\
 \t    [--mirror-binary-security URL]\n\
-\t    [--mirror-binary-volatile URL]\n\
+\t    [--mirror-binary-updates URL]\n\
 \t    [--mirror-binary-backports URL]\n\
 \t    [--mirror-debian-installer URL]\n\
 \t    [--mode debian|emdebian|ubuntu|kubuntu]\n\
@@ -128,7 +128,7 @@ USAGE="${PROGRAM}   [--apt apt|aptitude]\n\
 \t    [--syslinux-theme THEME_SUFFIX]\n\
 \t    [--tasksel apt|aptitude|tasksel]\n\
 \t    [--templates PATH]\n\
-\t    [--volatile true|false]\n\
+\t    [--updates true|false]\n\
 \t    [--backports true|false]\n\
 \t    [--exposed-root true|false]\n\
 \t    [--verbose]\n\
@@ -145,13 +145,13 @@ Local_arguments ()
 		cache-stages:,debconf-frontend:,debconf-nowarnings:,debconf-priority:,dump,
 		initramfs:,initramfs-compression:,initsystem:,fdisk:,losetup:,mode:,system:,root-command:,use-fakeroot:,tasksel:,
 		templates:,architectures:,clean,
-		distribution:,parent-distribution:,parent-debian-installer-distribution:,parent-mirror-bootstrap:,parent-mirror-chroot:,parent-mirror-chroot-security:,parent-mirror-chroot-volatile:,parent-mirror-chroot-backports:,parent-mirror-binary:,
-		parent-mirror-binary-security:,parent-mirror-binary-volatile:,parent-mirror-binary-backports:,parent-mirror-debian-installer:,
-		mirror-bootstrap:,mirror-chroot:,mirror-chroot-security:,mirror-chroot-volatile:,mirror-chroot-backports:,mirror-binary:,
-		mirror-binary-security:,mirror-binary-volatile:,mirror-binary-backports:,mirror-debian-installer:,
+		distribution:,parent-distribution:,parent-debian-installer-distribution:,parent-mirror-bootstrap:,parent-mirror-chroot:,parent-mirror-chroot-security:,parent-mirror-chroot-updates:,parent-mirror-chroot-backports:,parent-mirror-binary:,
+		parent-mirror-binary-security:,parent-mirror-binary-updates:,parent-mirror-binary-backports:,parent-mirror-debian-installer:,
+		mirror-bootstrap:,mirror-chroot:,mirror-chroot-security:,mirror-chroot-updates:,mirror-chroot-backports:,mirror-binary:,
+		mirror-binary-security:,mirror-binary-updates:,mirror-binary-backports:,mirror-debian-installer:,
 		archives:,archive-areas:,parent-archive-areas:,chroot-filesystem:,exposed-root:,
 		gzip-options:,hooks:,interactive:,keyring-packages:,linux-flavours:,linux-packages:,
-		security:,volatile:,backports:,binary-filesystem:,binary-images:,
+		security:,updates:,backports:,binary-filesystem:,binary-images:,
 		apt-indices:,bootappend-install:,bootappend-live:,bootappend-failsafe:,bootloader:,checksums:,compression:,config:,zsync:,build-with-chroot:,
 		debian-installer:,debian-installer-distribution:,debian-installer-preseedfile:,debian-installer-gui:,
 		grub-splash:,isohybrid-options:,hdd-label:,hdd-size:,iso-application:,iso-preparer:,iso-publisher:,
@@ -404,8 +404,8 @@ Local_arguments ()
 				shift 2
 				;;
 
-			--parent-mirror-chroot-volatile)
-				LB_PARENT_MIRROR_CHROOT_VOLATILE="${2}"
+			--parent-mirror-chroot-updates)
+				LB_PARENT_MIRROR_CHROOT_UPDATES="${2}"
 				shift 2
 				;;
 
@@ -424,8 +424,8 @@ Local_arguments ()
 				shift 2
 				;;
 
-			--parent-mirror-binary-volatile)
-				LB_PARENT_MIRROR_BINARY_VOLATILE="${2}"
+			--parent-mirror-binary-updates)
+				LB_PARENT_MIRROR_BINARY_UPDATES="${2}"
 				shift 2
 				;;
 
@@ -454,8 +454,8 @@ Local_arguments ()
 				shift 2
 				;;
 
-			--mirror-chroot-volatile)
-				LB_MIRROR_CHROOT_VOLATILE="${2}"
+			--mirror-chroot-updates)
+				LB_MIRROR_CHROOT_UPDATES="${2}"
 				shift 2
 				;;
 
@@ -474,8 +474,8 @@ Local_arguments ()
 				shift 2
 				;;
 
-			--mirror-binary-volatile)
-				LB_MIRROR_BINARY_VOLATILE="${2}"
+			--mirror-binary-updates)
+				LB_MIRROR_BINARY_UPDATES="${2}"
 				shift 2
 				;;
 
@@ -550,8 +550,8 @@ Local_arguments ()
 				shift 2
 				;;
 
-			--volatile)
-				LB_VOLATILE="${2}"
+			--updates)
+				LB_UPDATES="${2}"
 				shift 2
 				;;
 
@@ -1123,9 +1123,9 @@ LB_PARENT_MIRROR_CHROOT="${LB_PARENT_MIRROR_CHROOT}"
 # (Default: ${LB_PARENT_MIRROR_CHROOT_SECURITY})
 LB_PARENT_MIRROR_CHROOT_SECURITY="${LB_PARENT_MIRROR_CHROOT_SECURITY}"
 
-# \$LB_PARENT_MIRROR_CHROOT_VOLATILE: set volatile parent mirror to fetch packages from
-# (Default: ${LB_PARENT_MIRROR_CHROOT_VOLATILE})
-LB_PARENT_MIRROR_CHROOT_VOLATILE="${LB_PARENT_MIRROR_CHROOT_VOLATILE}"
+# \$LB_PARENT_MIRROR_CHROOT_UPDATES: set updates parent mirror to fetch packages from
+# (Default: ${LB_PARENT_MIRROR_CHROOT_UPDATES})
+LB_PARENT_MIRROR_CHROOT_UPDATES="${LB_PARENT_MIRROR_CHROOT_UPDATES}"
 
 # \$LB_PARENT_MIRROR_CHROOT_BACKPORTS: set backports parent mirror to fetch packages from
 # (Default: ${LB_PARENT_MIRROR_CHROOT_BACKPORTS})
@@ -1139,9 +1139,9 @@ LB_PARENT_MIRROR_BINARY="${LB_PARENT_MIRROR_BINARY}"
 # (Default: ${LB_PARENT_MIRROR_BINARY_SECURITY})
 LB_PARENT_MIRROR_BINARY_SECURITY="${LB_PARENT_MIRROR_BINARY_SECURITY}"
 
-# \$LB_PARENT_MIRROR_BINARY_VOLATILE: set volatile parent mirror which ends up in the image
-# (Default: ${LB_PARENT_MIRROR_BINARY_VOLATILE})
-LB_PARENT_MIRROR_BINARY_VOLATILE="${LB_PARENT_MIRROR_BINARY_VOLATILE}"
+# \$LB_PARENT_MIRROR_BINARY_UPDATES: set updates parent mirror which ends up in the image
+# (Default: ${LB_PARENT_MIRROR_BINARY_UPDATES})
+LB_PARENT_MIRROR_BINARY_UPDATES="${LB_PARENT_MIRROR_BINARY_UPDATES}"
 
 # \$LB_PARENT_MIRROR_BINARY_BACKPORTS: set backports parent mirror which ends up in the image
 # (Default: ${LB_PARENT_MIRROR_BINARY_BACKPORTS})
@@ -1163,9 +1163,9 @@ LB_MIRROR_CHROOT="${LB_MIRROR_CHROOT}"
 # (Default: ${LB_MIRROR_CHROOT_SECURITY})
 LB_MIRROR_CHROOT_SECURITY="${LB_MIRROR_CHROOT_SECURITY}"
 
-# \$LB_MIRROR_CHROOT_VOLATILE: set volatile mirror to fetch packages from
-# (Default: ${LB_MIRROR_CHROOT_VOLATILE})
-LB_MIRROR_CHROOT_VOLATILE="${LB_MIRROR_CHROOT_VOLATILE}"
+# \$LB_MIRROR_CHROOT_UPDATES: set updates mirror to fetch packages from
+# (Default: ${LB_MIRROR_CHROOT_UPDATES})
+LB_MIRROR_CHROOT_UPDATES="${LB_MIRROR_CHROOT_UPDATES}"
 
 # \$LB_MIRROR_CHROOT_BACKPORTS: set backports mirror to fetch packages from
 # (Default: ${LB_MIRROR_CHROOT_BACKPORTS})
@@ -1179,9 +1179,9 @@ LB_MIRROR_BINARY="${LB_MIRROR_BINARY}"
 # (Default: ${LB_MIRROR_BINARY_SECURITY})
 LB_MIRROR_BINARY_SECURITY="${LB_MIRROR_BINARY_SECURITY}"
 
-# \$LB_MIRROR_BINARY_VOLATILE: set volatile mirror which ends up in the image
-# (Default: ${LB_MIRROR_BINARY_VOLATILE})
-LB_MIRROR_BINARY_VOLATILE="${LB_MIRROR_BINARY_VOLATILE}"
+# \$LB_MIRROR_BINARY_UPDATES: set updates mirror which ends up in the image
+# (Default: ${LB_MIRROR_BINARY_UPDATES})
+LB_MIRROR_BINARY_UPDATES="${LB_MIRROR_BINARY_UPDATES}"
 
 # \$LB_MIRROR_BINARY_BACKPORTS: set backports mirror which ends up in the image
 # (Default: ${LB_MIRROR_BINARY_BACKPORTS})
@@ -1265,9 +1265,9 @@ LB_LINUX_PACKAGES="${LB_LINUX_PACKAGES}"
 # (Default: ${LB_SECURITY})
 LB_SECURITY="${LB_SECURITY}"
 
-# \$LB_VOLATILE: enable volatile updates
-# (Default: ${LB_VOLATILE})
-LB_VOLATILE="${LB_VOLATILE}"
+# \$LB_UPDATES: enable updates updates
+# (Default: ${LB_UPDATES})
+LB_UPDATES="${LB_UPDATES}"
 
 # \$LB_BACKPORTS: enable backports updates
 # (Default: ${LB_BACKPORTS})

diff --git a/functions/defaults.sh b/functions/defaults.sh
index 98ace32..bd7f0a4 100755
--- a/functions/defaults.sh
+++ b/functions/defaults.sh
@@ -434,30 +434,30 @@ Set_defaults ()
 			;;
 	esac
 
 	# Setting volatile mirror to fetch packages from
 	case "${LB_MODE}" in
 		debian|progress)
-			LB_PARENT_MIRROR_CHROOT_VOLATILE="${LB_PARENT_MIRROR_CHROOT_VOLATILE:-${LB_PARENT_MIRROR_CHROOT}}"
-			LB_MIRROR_CHROOT_VOLATILE="${LB_MIRROR_CHROOT_VOLATILE:-${LB_MIRROR_CHROOT}}"
+			LB_PARENT_MIRROR_CHROOT_UPDATES="${LB_PARENT_MIRROR_CHROOT_UPDATES:-${LB_PARENT_MIRROR_CHROOT}}"
+			LB_MIRROR_CHROOT_UPDATES="${LB_MIRROR_CHROOT_UPDATES:-${LB_MIRROR_CHROOT}}"
 			;;
 
 		ubuntu|kubuntu)
 			case "${LB_ARCHITECTURES}" in
 				amd64|i386)
-					LB_MIRROR_CHROOT_VOLATILE="${LB_MIRROR_CHROOT_VOLATILE:-http://archive.ubuntu.com/ubuntu/}"
+					LB_MIRROR_CHROOT_UPDATES="${LB_MIRROR_CHROOT_UPDATES:-http://archive.ubuntu.com/ubuntu/}"
 					;;
 
 				*)
-					LB_MIRROR_CHROOT_VOLATILE="${LB_MIRROR_CHROOT_VOLATILE:-http://ports.ubuntu.com/ubuntu-ports/}"
+					LB_MIRROR_CHROOT_UPDATES="${LB_MIRROR_CHROOT_UPDATES:-http://ports.ubuntu.com/ubuntu-ports/}"
 					;;
 			esac
 
-			LB_PARENT_MIRROR_CHROOT_VOLATILE="${LB_PARENT_MIRROR_CHROOT_VOLATILE:-${LB_PARENT_MIRROR_CHROOT}}"
+			LB_PARENT_MIRROR_CHROOT_UPDATES="${LB_PARENT_MIRROR_CHROOT_UPDATES:-${LB_PARENT_MIRROR_CHROOT}}"
 			;;
 
 		*)
-			LB_PARENT_MIRROR_CHROOT_VOLATILE="${LB_PARENT_MIRROR_CHROOT_VOLATILE:-none}"
-			LB_MIRROR_CHROOT_VOLATILE="${LB_MIRROR_CHROOT_VOLATILE:-none}"
+			LB_PARENT_MIRROR_CHROOT_UPDATES="${LB_PARENT_MIRROR_CHROOT_UPDATES:-none}"
+			LB_MIRROR_CHROOT_UPDATES="${LB_MIRROR_CHROOT_UPDATES:-none}"
 			;;
 	esac
 
@@ -542,34 +542,34 @@ Set_defaults ()
 			;;
 	esac
 
 	# Setting volatile mirror which ends up in the image
 	case "${LB_MODE}" in
 		debian)
-			LB_MIRROR_BINARY_VOLATILE="${LB_MIRROR_BINARY_VOLATILE:-${LB_MIRROR_BINARY}}"
-			LB_PARENT_MIRROR_BINARY_VOLATILE="${LB_PARENT_MIRROR_BINARY_VOLATILE:-${LB_PARENT_MIRROR_BINARY}}"
+			LB_MIRROR_BINARY_UPDATES="${LB_MIRROR_BINARY_UPDATES:-${LB_MIRROR_BINARY}}"
+			LB_PARENT_MIRROR_BINARY_UPDATES="${LB_PARENT_MIRROR_BINARY_UPDATES:-${LB_PARENT_MIRROR_BINARY}}"
 			;;
 
 		progress)
-			LB_PARENT_MIRROR_BINARY_VOLATILE="${LB_PARENT_MIRROR_BINARY_VOLATILE:-${LB_PARENT_MIRROR_BINARY}}"
-			LB_MIRROR_BINARY_VOLATILE="${LB_MIRROR_BINARY_VOLATILE:-${LB_MIRROR_BINARY}}"
+			LB_PARENT_MIRROR_BINARY_UPDATES="${LB_PARENT_MIRROR_BINARY_UPDATES:-${LB_PARENT_MIRROR_BINARY}}"
+			LB_MIRROR_BINARY_UPDATES="${LB_MIRROR_BINARY_UPDATES:-${LB_MIRROR_BINARY}}"
 			;;
 
 		ubuntu|kubuntu)
 			case "${LB_ARCHITECTURES}" in
 				amd64|i386)
-					LB_MIRROR_BINARY_VOLATILE="${LB_MIRROR_BINARY_VOLATILE:-http://archive.ubuntu.com/ubuntu/}"
+					LB_MIRROR_BINARY_UPDATES="${LB_MIRROR_BINARY_UPDATES:-http://archive.ubuntu.com/ubuntu/}"
 					;;
 
 				*)
-					LB_MIRROR_BINARY_VOLATILE="${LB_MIRROR_BINARY_VOLATILE:-http://ports.ubuntu.com/ubuntu-ports/}"
+					LB_MIRROR_BINARY_UPDATES="${LB_MIRROR_BINARY_UPDATES:-http://ports.ubuntu.com/ubuntu-ports/}"
 					;;
 			esac
 
-			LB_PARENT_MIRROR_BINARY_VOLATILE="${LB_PARENT_MIRROR_BINARY_VOLATILE:-${LB_PARENT_MIRROR_BINARY}}"
+			LB_PARENT_MIRROR_BINARY_UPDATES="${LB_PARENT_MIRROR_BINARY_UPDATES:-${LB_PARENT_MIRROR_BINARY}}"
 			;;
 
 		*)
-			LB_PARENT_MIRROR_BINARY_VOLATILE="${LB_PARENT_MIRROR_BINARY_VOLATILE:-none}"
+			LB_PARENT_MIRROR_BINARY_UPDATES="${LB_PARENT_MIRROR_BINARY_UPDATES:-none}"
 			;;
 	esac
 
@@ -850,14 +850,14 @@ Set_defaults ()
 			;;
 	esac
 
-	# Setting volatile updates option
+	# Setting updates updates option
 	case "${LB_PARENT_DISTRIBUTION}" in
 		wheezy|jessie|sid)
-			LB_VOLATILE="${LB_VOLATILE:-false}"
+			LB_UPDATES="${LB_UPDATES:-false}"
 			;;
 
 		*)
-			LB_VOLATILE="${LB_VOLATILE:-true}"
+			LB_UPDATES="${LB_UPDATES:-true}"
 			;;
 	esac
 
@@ -434,30 +434,30 @@ Set_defaults ()
 	esac
 
-	# Setting volatile mirror to fetch packages from
+	# Setting updates mirror to fetch packages from
 	case "${LB_MODE}" in
 		debian|progress)
@@ -542,34 +542,34 @@ Set_defaults ()
 	esac
 
-	# Setting volatile mirror which ends up in the image
+	# Setting updates mirror which ends up in the image
 	case "${LB_MODE}" in
 		debian)
-- 
live-build



More information about the debian-live-changes mailing list